SuperLU: SRC/supermatrix.h File Reference

SuperLU 7.0.1

Data Structures | Typedefs | Enumerations
supermatrix.h File Reference

Matrix type definitions. More...

This graph shows which files directly or indirectly include this file:

Go to the source code of this file.

## Data Structures
struct | SuperMatrix
struct | NCformat
struct | NRformat
struct | SCformat
struct | SCPformat
struct | NCPformat
struct | DNformat
struct | NRformat_loc
struct | NRformat_loc3d

## Typedefs
typedef struct NRformat_loc3d | NRformat_loc3d

## Enumerations
enum | Stype_t { SLU_NC , SLU_NCP , SLU_NR , SLU_SC , SLU_SCP , SLU_SR , SLU_DN , SLU_NR_loc }
enum | Dtype_t { SLU_S , SLU_D , SLU_C , SLU_Z }
enum | Mtype_t { SLU_GE , SLU_TRLU , SLU_TRUU , SLU_TRL , SLU_TRU , SLU_SYL , SLU_SYU , SLU_HEL , SLU_HEU }

## Detailed Description

Copyright (c) 2003, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from U.S. Dept. of Energy)

All rights reserved.

The source code is distributed under BSD license, see the file License.txt at the top-level directory.

## Typedef Documentation

## ◆ NRformat_loc3d

typedef struct NRformat_loc3d NRformat_loc3d

## Enumeration Type Documentation

## ◆ Dtype_t

enum Dtype_t

Enumerator
SLU_S |
SLU_D |
SLU_C |
SLU_Z |

## ◆ Mtype_t

enum Mtype_t

Enumerator
SLU_GE |
SLU_TRLU |
SLU_TRUU |
SLU_TRL |
SLU_TRU |
SLU_SYL |
SLU_SYU |
SLU_HEL |
SLU_HEU |

## ◆ Stype_t

enum Stype_t

Enumerator
SLU_NC |
SLU_NCP |
SLU_NR |
SLU_SC |
SLU_SCP |
SLU_SR |
SLU_DN |
SLU_NR_loc |